﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Media;
using Microsoft.Maps.MapControl;

namespace MapEvents
{
    public partial class MainPage : UserControl
    {
        private Dictionary<string, TextBlock> eventBlocks = new Dictionary<string, TextBlock>();
        private Dictionary<string, int> eventCount = new Dictionary<string, int>();

        public MainPage()
        {
            InitializeComponent();

            // View Change Events
            MyMap.ViewChangeStart += new EventHandler<MapEventArgs>(MyMap_ViewChangeStart);
            MyMap.ViewChangeEnd += new EventHandler<MapEventArgs>(MyMap_ViewChangeEnd);
            MyMap.ViewChangeOnFrame += new EventHandler<MapEventArgs>(MyMap_ViewChangeOnFrame);
            MyMap.TargetViewChanged += new EventHandler<MapEventArgs>(MyMap_TargetViewChanged);

            // Mode Events
            MyMap.ModeChanged += new EventHandler<MapEventArgs>(MyMap_ModeChanged);

            // Mouse Events
            MyMap.MouseDoubleClick += new EventHandler<MapMouseEventArgs>(MyMap_MouseDoubleClick);
            MyMap.MousePan += new EventHandler<MapMouseDragEventArgs>(MyMap_MousePan);
            MyMap.MouseWheel += new MouseWheelEventHandler(MyMap_MouseWheel);
            MyMap.MouseDragBox += new EventHandler<MapMouseDragEventArgs>(MyMap_MouseDragBox);
            MyMap.MouseClick += new EventHandler<MapMouseEventArgs>(MyMap_MouseClick);
            MyMap.MouseLeftButtonDown += new MouseButtonEventHandler(MyMap_MouseLeftButtonDown);
            MyMap.MouseLeftButtonUp += new MouseButtonEventHandler(MyMap_MouseLeftButtonUp);

            // Keyboard events
            MyMap.KeyPress += new EventHandler<MapKeyPressEventArgs>(MyMap_KeyPress);
            MyMap.KeyHeld += new EventHandler<MapKeyHeldEventArgs>(MyMap_KeyHeld);

        }

        #region View Change Events

        void MyMap_ViewChangeStart(object sender, MapEventArgs e)
        {
            ShowEvent("ViewChangeStart");
        }

        void MyMap_ViewChangeEnd(object sender, MapEventArgs e)
        {
            ShowEvent("ViewChangeEnd");
        }

        void MyMap_ViewChangeOnFrame(object sender, MapEventArgs e)
        {
            ShowEvent("ViewChangeOnFrame");
        }

        void MyMap_TargetViewChanged(object sender, MapEventArgs e)
        {
            ShowEvent("TargetViewChange");
        }

        #endregion

        #region Map Mode Events

        void MyMap_ModeChanged(object sender, MapEventArgs e)
        {
            ShowEvent("ModeChanged");
        }
        #endregion

        #region Mouse Events

        void MyMap_MouseClick(object sender, MapMouseEventArgs e)
        {
            ShowEvent("MouseClick");
        }

        void MyMap_MouseDragBox(object sender, MapMouseDragEventArgs e)
        {
            ShowEvent("MouseDragBox");
        }

        void MyMap_MouseWheel(object sender, MouseWheelEventArgs e)
        {
            ShowEvent("MouseWheel");
        }

        void MyMap_MousePan(object sender, MapMouseDragEventArgs e)
        {
            ShowEvent("MousePan");
        }

        void MyMap_MouseDoubleClick(object sender, MapMouseEventArgs e)
        {
            ShowEvent("MouseDoubleClick");
        }

        void MyMap_MouseLeftButtonUp(object sender, MouseButtonEventArgs e)
        {
            ShowEvent("MouseLeftButtonUp");
        }

        void MyMap_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            ShowEvent("MouseLeftButtonDown");
        }

        #endregion


        #region Keyboard events

        void MyMap_KeyPress(object sender, MapKeyPressEventArgs e)
        {
            ShowEvent("KeyPress");
        }

        void MyMap_KeyHeld(object sender, MapKeyHeldEventArgs e)
        {
            ShowEvent("KeyHeld");
        }

        #endregion

        void ShowEvent(string eventName)
        {
            if (!eventBlocks.ContainsKey(eventName))
            {
                TextBlock tb = new TextBlock();
                tb.Foreground = new SolidColorBrush(Colors.Black);
                tb.Margin = new Thickness(5);
                tb.FontSize = 20;
                eventBlocks.Add(eventName, tb);
                eventCount.Add(eventName, 0);
                eventsPanel.Children.Add(tb);
            }

            eventCount[eventName]++;
            eventBlocks[eventName].Text = eventName + ": [" + eventCount[eventName].ToString() + " times] " + DateTime.Now.ToString("HH:mm:ss:ffff");
        }
    }
 
}
